@@ -15,7 +15,7 @@ with the other side.  This same code is used both on client and server side.
 */
 
 #include "includes.h"
-RCSID("$Id: packet.c,v 1.10 1999/10/31 12:31:30 bg Exp $");
+RCSID("$Id: packet.c,v 1.11 1999/11/29 13:36:44 bg Exp $");
 
 #include "xmalloc.h"
 #include "randoms.h"
@@ -73,6 +73,9 @@ static int packet_compression = 0;
 /* Pointer to the random number generator state. */
 static RandomState *random_state;
 
+/* default maximum packet size */
+int max_packet_size = 32768;
+
 /* Flag indicating whether this module has been initialized. */
 static int initialized = 0;
 
@@ -715,3 +718,20 @@ int packet_is_interactive()
 {
   return interactive_mode;
 }
+
+int
+packet_set_maxsize(int s)
+{
+  static int called = 0;
+  if (called) {
+    log("packet_set_maxsize: called twice: old %d new %d", max_packet_size, s);
+    return -1;
+  }
+  if (s < 4*1024 || s > 1024*1024) {
+    log("packet_set_maxsize: bad size %d", s);
+    return -1;
+  }
+  log("packet_set_maxsize: setting to %d", s);
+  max_packet_size = s;
+  return s;
+}
